@@ -32,7 +32,7 @@ use file_locker::FileLock;
 #[cfg(feature = "system-theme")]
 pub use linicon_theme::get_icon_theme as get_system_theme;
 use memmap2::Mmap;
-use parser::{parse_index, Directory, IndexHeader};
+use parser::{parse_index, Directory};
 use std::{
     cmp::{Eq, PartialEq},
     collections::{HashMap, VecDeque},
@@ -158,18 +158,16 @@ pub struct IconIter<'a> {
 #[derive(Debug)]
 struct IconIterState<'a> {
     theme_name: String,
-    /// Places to search for icon themes
-    sps: Vec<PathBuf>,
     /// Directories for the current theme
     theme_dirs: Vec<PathBuf>,
     /// Locked index file handle
+    #[allow(dead_code)]
     file_lock: FileLock,
     /// Index file mem-map
+    #[allow(dead_code)]
     mmap: Mmap,
     /// Iterator over directories in the index file
     dir_iter: IntoIter<Directory<'a>>,
-    /// The index file header metadata
-    index_header: IndexHeader,
     /// List of fallback themes
     fallbacks: VecDeque<String>,
 }
@@ -204,7 +202,7 @@ impl<'a> IconIterState<'a> {
             }
         })?;
 
-        // SAFETY: the Mmap struct should never outlive dir_iter or index_header
+        // SAFETY: the Mmap struct should never outlive dir_iter
         let (index_header, dirs) =
             parse_index(unsafe { std::mem::transmute(mmap.as_ref()) })
                 .map_err(|e| LiniconError::ParseIndex {
@@ -228,12 +226,10 @@ impl<'a> IconIterState<'a> {
 
         Ok(IconIterState {
             theme_name,
-            sps,
             theme_dirs,
             file_lock,
             mmap,
             dir_iter: dirs.into_iter(),
-            index_header,
             fallbacks,
         })
     }
